==> kadu_0.6.0.2.orig.tar.gz: kadu/modules/history/translations/history_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Save history</source>
        <translation>Verlauf speichern</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Speichere Nachrichten im Verlauf</translation>
    </message>
    <message>
        <source>Status changes</source>
        <translation>Zustandsänderungen</translation>
    </message>
    <message>
        <source>Don&apos;t show status changes</source>
        <translation>Zeige keine Zustandsänderungen</translation>
    </message>
    <message>
        <source>Don&apos;t show status changes in history</source>
        <translation>Zeige keine Zustandsänderungen im Verlauf</translation>
    </message>
    <message>
        <source>Don&apos;t save status changes</source>
        <translation>Speichere keine Zusandsänderungen</translation>
    </message>
    <message>
        <source>Don&apos;t save status changes in history</source>
        <translation>Speichere keine Zusandsänderungen im Verlauf</translation>
    </message>
    <message>
        <source>Citation</source>
        <translation>Zitation</translation>
    </message>
    <message>
        <source>Message citation in chat window</source>
        <translation>Anzeige alter Nachrichten im Chat-Fenster</translation>
    </message>
    <message>
        <source>Don&apos;t cite messages older than</source>
        <translation>Zeige keine Nachrichten, die älter sind als</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Kürzel</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Zeige Verlauf</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Suche</translation>
    </message>
    <message>
        <source>Find &amp;next</source>
        <translation>Suche &amp;nächstes Vorkommen</translation>
    </message>
    <message>
        <source>Find &amp;previous</source>
        <translation>Suche &amp;vorheriges Vorkommen</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Erreichbar</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Versteckt</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Unerreichbar</translation>
    </message>
    <message>
        <source>Uins</source>
        <translation>GG-Nummern</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation>Zeige Zustandsänderungen</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <source>Clear history?</source>
        <translation>Verlauf leeren?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <source>Show history</source>
        <translation>Zeige Verlauf</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Verlauf leeren</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>%1 Tage %2 Stunden</translation>
    </message>
    <message>
        <source>The following users were deleted:
%0
Do you want to remove history as well?</source>
        <translation>Die folgenen Kontate werden entfernt:
%0
Wollen Sie den Verlauf dieser leeren?</translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <source>Search history</source>
        <translation>Suche im Verlauf</translation>
    </message>
    <message>
        <source>&amp;From:</source>
        <translation>&amp;Von:</translation>
    </message>
    <message>
        <source>day</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>month</source>
        <translation>Monat</translation>
    </message>
    <message>
        <source>year</source>
        <translation>Jahr</translation>
    </message>
    <message>
        <source>hour</source>
        <translation>Stunde</translation>
    </message>
    <message>
        <source>minute</source>
        <translation>Minute</translation>
    </message>
    <message>
        <source>&amp;To:</source>
        <translation>&amp;Bis:</translation>
    </message>
    <message>
        <source>Find Criteria</source>
        <translation>Suchkriterien</translation>
    </message>
    <message>
        <source>&amp;Pattern</source>
        <translation>&amp;Muster</translation>
    </message>
    <message>
        <source>&amp;Status</source>
        <translation>&amp;Zustand</translation>
    </message>
    <message>
        <source>Pattern</source>
        <translation>Muster</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Zustand</translation>
    </message>
    <message>
        <source>&amp;Reverse find</source>
        <translation>&amp;Suche rückwärts</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Suche</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbruch</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.1.orig.tar.gz: kadu/modules/history/translations/history_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Speichere Nachrichten im Verlauf</translation>
    </message>
    <message>
        <source>Status changes</source>
        <translation>Zustandsänderungen</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation>Zeige Zustandsänderungen</translation>
    </message>
    <message>
        <source>Show status changes in history</source>
        <translation>Zeige Zustandsänderungen im Verlauf</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Speichere Zusandsänderungen</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Speichere Zusandsänderungen im Verlauf</translation>
    </message>
    <message>
        <source>Citation</source>
        <translation>Zitation</translation>
    </message>
    <message>
        <source>Message citation in chat window</source>
        <translation>Anzeige alter Nachrichten im Chat-Fenster</translation>
    </message>
    <message>
        <source>Don&apos;t cite messages older than</source>
        <translation>Zeige keine Nachrichten, die älter sind als</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Kürzel</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Zeige Verlauf</translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>History</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Suche</translation>
    </message>
    <message>
        <source>Find &amp;next</source>
        <translation>Suche &amp;nächstes Vorkommen</translation>
    </message>
    <message>
        <source>Find &amp;previous</source>
        <translation>Suche &amp;vorheriges Vorkommen</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Erreichbar</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Beschäftigt</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Versteckt</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Unerreichbar</translation>
    </message>
    <message>
        <source>Uins</source>
        <translation>GG-Nummern</translation>
    </message>
    <message>
        <source>Show status changes</source>
        <translation>Zeige Zustandsänderungen</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Unbekannt</translation>
    </message>
</context>
<context>
    <name>HistoryManager</name>
    <message>
        <source>Clear history?</source>
        <translation>Verlauf leeren?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nein</translation>
    </message>
</context>
<context>
    <name>HistoryModule</name>
    <message>
        <source>Show history</source>
        <translation>Zeige Verlauf</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Verlauf leeren</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>%1 Tage %2 Stunden</translation>
    </message>
    <message>
        <source>The following users were deleted:
%0Do you want to remove history as well?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistorySearchDialog</name>
    <message>
        <source>Search history</source>
        <translation>Suche im Verlauf</translation>
    </message>
    <message>
        <source>&amp;From:</source>
        <translation>&amp;Von:</translation>
    </message>
    <message>
        <source>day</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>month</source>
        <translation>Monat</translation>
    </message>
    <message>
        <source>year</source>
        <translation>Jahr</translation>
    </message>
    <message>
        <source>hour</source>
        <translation>Stunde</translation>
    </message>
    <message>
        <source>minute</source>
        <translation>Minute</translation>
    </message>
    <message>
        <source>Find Criteria</source>
        <translation>Suchkriterien</translation>
    </message>
    <message>
        <source>&amp;Pattern</source>
        <translation>&amp;Muster</translation>
    </message>
    <message>
        <source>&amp;Status</source>
        <translation>&amp;Zustand</translation>
    </message>
    <message>
        <source>Pattern</source>
        <translation>Muster</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Zustand</translation>
    </message>
    <message>
        <source>&amp;Reverse find</source>
        <translation>&amp;Suche rückwärts</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Suche</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Zurücksetzen</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbruch</translation>
    </message>
</context>
</TS>
